@@ -97,6 +97,10 @@ void oer_debug(int level, const char *fmt, ...)
                 va_start(ap, fmt);
                 if(do_output) {
                         vfprintf(mystate->logto, fmt, ap);
+			if(mystate->outputcounter >= OER_FORCE_FLUSH) {
+				fflush(mystate->logto);
+				mystate->outputcounter = 0;
+			}
 		}
 		if(do_console) {
                         vfprintf(stdout, fmt, ap);
