@@ -219,15 +219,17 @@ int serverconnection()
 	memset(&servaddr, 0, sizeof(struct sockaddr_in));
 	servaddr.sin_family = AF_INET;
 	servaddr.sin_addr.s_addr = INADDR_ANY;
-	/* if we don't have a vhost, just use the default system hostname */
-	if(!mystate->vhost) {
-		if(gethostname(mystate->host, HOSTLEN) < 0) {
+	/* get system hostname */
+	if(gethostname(mystate->host, HOSTLEN) < 0) {
 #ifdef DEBUG
-			oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
+		oer_debug(OER_DEBUG_ERROR, "serverconnection->gethostname() failed: %s\n", strerror(errno));
 #endif
-			close(mystate->sockfd);
-			return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
-		}
+		close(mystate->sockfd);
+		return OER_SERVERCONNECTION_ERR_GETHOSTNAME;
+	}
+	if(strlen(mystate->vhost)) {
+		/* override with virtual host */
+		strncpy(mystate->host, mystate->vhost, HOSTLEN);
 	}
 	if((hptr = (struct hostent *) gethostbyname(mystate->host)) == NULL) {
 #ifndef _NO_H_ERRNO
@@ -254,7 +256,7 @@ int serverconnection()
 #endif
 	}
 	memcpy((char *) &servaddr.sin_addr, hptr->h_addr, hptr->h_length);
-	if(mystate->vhost) {
+	if(strlen(mystate->vhost)) {
 		/* bind is only necessary for vhost */
 		if(bind(mystate->sockfd, (struct sockaddr *) &servaddr, sizeof(struct sockaddr)) < 0) {
 #ifdef DEBUG
@@ -460,6 +462,10 @@ int handleserverdata()
 	/* here we log all the server traffic, prefix with timestamp */
 	if(index(mystate->flags, (int)'l') != NULL) {
 		fprintf(mystate->logfp, "%lu %s", (unsigned long) mystate->now, stringbuffer);
+		if(mystate->rawcounter >= OER_FORCE_FLUSH) {
+			fflush(mystate->logfp);
+			mystate->rawcounter = 0;
+		}
 	}
 	if((ptr = (char *) strstr(stringbuffer, "PING :")) != NULL) {
 		snprintf(pong, STRINGLEN, "PONG :%s", ptr + 6);
