@@ -263,7 +263,7 @@ enum OER_FLAGS_TYPE {
 #define OER_FLAGS_GLOBAL "bdfglmpqs"
 #define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwxX"
 #define OER_FLAGS_ADMIN "dn"
-#define OER_FLAGS_USER "!adfmovrx"
+#define OER_FLAGS_USER "!adfmnovrx"
 
 #define numofparams(x) (wordcount(x) - 1)
 
@@ -322,6 +322,7 @@ enum OER_FLAGS_TYPE {
 #define OER_BANVARS_NORMAL_BAN 3600
 #define OER_SAVE_INTERVAL 3600
 #define OER_ALLOWED_QUOTE_TIME_USEC 600000
+#define OER_FORCE_FLUSH 100
 #define Q_NICK "Q"
 /* Define if you want to show server idle percentage */
 /* #undef OER_UPTIME_SHOW_IDLE */
@@ -357,13 +358,14 @@ enum OER_FLAGS_TYPE {
 #define CONNECTION_STATE_PREFIXES "^~+=-"
 #define OER_MAX_LIST_LINES 5
 #define OER_UNKNOWN "unknown"
-#define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
+#define OER_HELP "For the oer user manual go to http://oer.equnet.org/um.php"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define DEFAULT_WORDBK_MESSAGE "word ban-kick triggered, have a nice life..."
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
-#define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-58, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_REALNAME "http://oer.equnet.org"
+#define OER_VERSION "oer version 1.0-59"
+#define OER_COPYRIGHT1 "Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -585,6 +587,8 @@ struct channel {
 	int allhostsknown;
 	int whoquery;
 	int requestop_now;
+	int seencounter;
+	int lastcounter;
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t join_ts;
@@ -628,8 +632,8 @@ struct state {
 	char flags[FLAGLEN + 1];
 	char prefix[MICROSTRINGLEN + 1];
 	char proxysetup[STRINGLEN + 1];
+        char vhost[HOSTLEN + 1];
 	int customuser;
-	int vhost;
 	int use_altnick;
 	int sockfd;
 	int loopforever;
@@ -640,6 +644,8 @@ struct state {
 	int quitting;
 	int reconnect;
 	int kickrs;
+	int rawcounter;
+	int outputcounter;
 	time_t now;
 	time_t startup;
 	time_t postnj_checks_at;
