@@ -104,7 +104,7 @@ int main(int argc, char *argv[])
 		oer_debug(OER_DEBUG_INFO, "%s: oer [-c] [-d <level>] [-h] [-o] [-s] [-v]\n", argv[0]);
 		exit(EXIT_SUCCESS);
 	}
-	oer_debug(OER_DEBUG_INFO, "%s\n\n", OER_COPYRIGHT1);
+	oer_debug(OER_DEBUG_INFO, "%s, %s\n\n", OER_VERSION, OER_COPYRIGHT1);
 	oer_debug(OER_DEBUG_INFO, "%s\n", OER_COPYRIGHT2);
 	if(do_version) {
 		exit(EXIT_SUCCESS);
@@ -163,36 +163,44 @@ int main(int argc, char *argv[])
         act.sa_flags = SA_RESTART;
         act.sa_handler = handlesignal;
         if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGHUP: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
 	}
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGINT, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGINT: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
 	}
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGTERM, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGTERM: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
 	}
-        if(sigaction(SIGHUP, &act, &old) < 0) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+        if(sigaction(SIGPIPE, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGPIPE: %s\n", strerror(errno));
+                exit(EXIT_FAILURE);
+	}
+        if(sigaction(SIGUSR1, &act, &old) < 0) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGUSR1: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
 	}
 #else
 	if(signal(SIGHUP, handlesignal) == SIG_ERR) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGHUP: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGHUP: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
 	if(signal(SIGINT, handlesignal) == SIG_ERR) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGINT: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGINT: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
 	if(signal(SIGTERM, handlesignal) == SIG_ERR) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGTERM: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGTERM: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
 	if(signal(SIGPIPE, handlesignal) == SIG_ERR) {
-                oer_debug(OER_DEBUG_INFO, "main->failed to set SIGPIPE: %s\n", strerror(errno));
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGPIPE: %s\n", strerror(errno));
+                exit(EXIT_FAILURE);
+        }
+	if(signal(SIGUSR1, handlesignal) == SIG_ERR) {
+                oer_debug(OER_DEBUG_FATAL, "main->failed to set SIGUSR1: %s\n", strerror(errno));
                 exit(EXIT_FAILURE);
         }
 #endif
@@ -209,8 +217,11 @@ int main(int argc, char *argv[])
 		}
 		oer_debug(OER_DEBUG_INFO, "main->debug output gets logged to %s\n", stringbuffer);
 	}
-	do_tempoutput = 0;
 	/* from now on we write to console and/or file */
+	do_tempoutput = 0;
+#ifdef DEBUG
+	oer_debug(OER_DEBUG_INFO, "main->%s (%s %s) starting up\n", OER_VERSION, __DATE__, __TIME__);
+#endif
 	if(!loadall()) {
 		oer_debug(OER_DEBUG_INFO, "main->loadall() failed\n");
 		exit(EXIT_FAILURE);
@@ -299,28 +310,33 @@ static void handlesignal(int signal)
 #ifdef DEBUG
         oer_debug(OER_DEBUG_NOISE, "handlesignal(%d)\n", signal);
 #endif
-	if(signal == SIGHUP) {
+	switch(signal) {
+	case SIGHUP:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "handlesignal->received SIGHUP, flushing disk I/O\n");
 #endif
 		flushall();
-		return;
-	}
-	if(signal == SIGINT || signal == SIGTERM) {
+		break;
+	case SIGINT:
+	case SIGTERM:
 		if(do_signals) {
 			snprintf(mystate->signoff, STRINGLEN, "received %s, leaving for now but I will return!", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
 			quit();
-			return;
-			
 		} else {
 #ifdef DEBUG
 			oer_debug(OER_DEBUG_INFO, "handlesignal->%s received, ignoring (do_signals = 0)\n", (signal == SIGINT) ? "SIGINT" : "SIGTERM");
 #endif
 		}
-	}
-	if(signal == SIGPIPE) {
+		break;
+	case SIGPIPE:
 		mystate->reconnect = OER_RECONNECT_ERROR;
 		strncpy(mystate->signoff, "received SIGPIPE, connecting to next server", STRINGLEN);
-		return;
+		break;
+	case SIGUSR1:
+		do_debug = (do_debug < OER_DEBUG_FLOOD) ? do_debug + 1 : OER_DEBUG_NONE;
+#ifdef DEBUG
+		oer_debug(OER_DEBUG_NONE, "handlesignal->SIGUSR1 received, new debug level is %d\n", do_debug);
+#endif
+		break;
 	}
 }
