@@ -274,9 +274,6 @@ void parseirc(char *serveroutput)
 		}
 		/* the topic is at restptr + restpos + 1 (first char is ':') */
 		gettopic(this, restptr + restpos + 1);
-#ifdef DEBUG
-		oer_debug(OER_DEBUG_INFO, "parseirc(332)->%s topic is %s\n", channel, restptr + restpos + 1);
-#endif
 		return;
 	}
 	if(!strcasecmp(command, "333")) {
@@ -520,6 +517,29 @@ void parseirc(char *serveroutput)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parseirc(439)->%s\n", restptr);
 #endif
+		restpos = 0;
+		if((restpos = parse(restptr, restpos, " ", channel, CHANLEN, 0)) < 0) {
+			return;
+		}
+		if((this = getchptr(channel)) == NULL) {
+			return;
+		}
+		if((ptr = strstr(restptr + restpos, "wait")) == NULL) {
+			return;
+		}
+		restpos += 5;
+		if((restpos = parse(restptr, restpos, " ", outstring, STRINGLEN, 0)) < 0) {
+			return;
+		}
+		i = atoi(outstring);
+		if(this->joining && !this->joined && i > 0) {
+			/* reset join status, retry when the server will accept our join */
+#ifdef DEBUG
+			oer_debug(OER_DEBUG_INFO, "parseirc(439)->trying to join channel again in %d seconds\n", i);
+#endif
+			this->joining = 0;
+			this->rejoin_at = mystate->now + i;
+		}
                 return;
         }
 	if(!strcasecmp(command, "441")) {
@@ -1248,7 +1268,7 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 			ppos = strlen(mystate->prefix);
 		}
 	}
-	if(is_command) {
+	if(is_command && !hasuserflags(this, userhost, "n", "")) {
 		/* the message is sent to a channel -> parse */
 		parsecommand(this->name, nick, userhost, message + ppos);
 	}
@@ -2338,7 +2358,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 		if(!proceed) {
 			return;
 		}
-		snprintf(outstring, WRITE_BUFFER_LENGTH, "%s -- oer was written in March of 2000. This version of oer was compiled %s %s. The C source of this oer version consists of %d lines totalling %d bytes.", OER_COPYRIGHT1, __DATE__, __TIME__, SOURCE_LINES, SOURCE_CHARS);
+		snprintf(outstring, WRITE_BUFFER_LENGTH, "%s, %s -- oer was written in March of 2000. This version of oer was compiled %s %s. The C source of this oer version consists of %d lines totalling %d bytes.", OER_VERSION, OER_COPYRIGHT1, __DATE__, __TIME__, SOURCE_LINES, SOURCE_CHARS);
 		sendreply((tochan) ? channel : nick, tochan, 0, OER_TIMED_PRIORITY_NORMAL, outstring);
 		return;
 	case OER_WHICHCOMMAND_UPTIME:
